install.packages("partykit")
library(partykit)

anaphora <- read.table(file=file.choose(), header = TRUE)
head(anaphora)
str(anaphora)
anaphora$TextType <- factor(anaphora$TextType)
anaphora$Animacy <- factor(anaphora$Animacy)
anaphora$AnteSynp <- factor(anaphora$AnteSynp)
anaphora$AnapType <- factor(anaphora$AnapType)
str(anaphora)
set.seed (129)

anaphora.ctree <- ctree(AnapType ~ PotlRefe + RefdPara + RefdSent + RefdClau + TextType + Animacy + AnteSynp, data = anaphora)
plot(anaphora.ctree)

######### 拟合（经典）随机森林
install.packages ("randomForest")
library (randomForest)
set.seed (129)

anaphora.rf <- randomForest(AnapType ~ PotlRefe + RefdPara + RefdSent 
                            + RefdClau + TextType + Animacy + AnteSynp, 
                            data=anaphora, ntree=1000, mtry=3, importance=TRUE)
print(anaphora.rf)

importance.scores <- importance(anaphora.rf, type=1)
varImpPlot(anaphora.rf, main="Variable Importance Scores", type=1)

partialPlot(x = anaphora.rf, 
            pred.data = anaphora,  
            x.var = AnteSynp,
            which.class = "Non-Zero",
            ylab = "Non-Zero")

partialPlot(x = anaphora.rf, 
            pred.data = anaphora,  
            x.var = RefdSent,
            which.class = "Non-Zero",
            ylab = "Non-Zero")


######### 拟合条件推断森林
install.packages("party")
library (party)
set.seed (129)

anaphora.cif <- cforest(AnapType ~ PotlRefe + RefdPara + RefdSent + RefdClau + TextType + Animacy + AnteSynp, 
                        data=anaphora, 
                        controls=cforest_unbiased(ntree=1000, mtry=3))

pred.cif.oob <- predict(anaphora.cif, OOB = TRUE)
table(pred.cif.oob, anaphora$AnapType)
(795+904)/1841

importance.scores <- varimp(anaphora.cif, conditional=TRUE)
dotchart(sort(importance.scores), main = "Conditional Variable Importance Scores")


install.packages("pdp")
library(pdp)

pd.AnteSynp <- partial(object=anaphora.cif, 
                       pred.var="AnteSynp",
                       prob=TRUE)
plotPartial(object=pd.AnteSynp, 
            main="Partial Dependence on AnteSynp",
            ylab="Non-Zero")


pd.RefdSent <- partial(object=anaphora.cif, 
                       pred.var="RefdSent",
                       prob=TRUE)
plotPartial(object=pd.RefdSent, 
            main="Partial Dependence on RefdSent",
            ylab="Non-Zero")
